@@ -46,8 +46,8 @@ class Navigator : public QWidget
     void insertScrollKeeperDocs( NavigatorItem *parent );
     void insertInfoDocs( NavigatorItem *parentItem );
     void insertKCMDocs(const QString &, NavigatorItem*parent, const QString &);
-    void insertIOSlaveDocs(const QString &, NavigatorItem*parent);
     
+    void insertIOWorkerDocs(const QString &, NavigatorItem*parent);
     void createItemFromDesktopFile( NavigatorItem *item, const QString &name );
 
     void clearSelection();
